"use strict";

var _react = require("react");
var _react2 = require("@testing-library/react");
var _vitest = require("vitest");
require("@testing-library/jest-dom");
var _index = require("../index");
var _styles = require("../styles");
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _div, _div2, _ExampleComponent2, _div3, _div4, _Transition3, _Transition4, _div5, _div6, _div7, _div8, _div9, _div10, _div11;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
const COMPONENT_TEXT = 'Component Text';
const getClass = (type, phase) => {
  const classNames = (0, _styles.getClassNames)(type);
  return classNames[phase];
};
class ExampleComponent extends _react.Component {
  render() {
    return _div || (_div = (0, _jsxRuntime.jsx)("div", {
      children: COMPONENT_TEXT
    }));
  }
}
ExampleComponent.displayName = "ExampleComponent";
describe('<Transition />', () => {
  let consoleWarningMock;
  let consoleErrorMock;
  beforeEach(() => {
    // Mocking console to prevent test output pollution and expect for messages
    consoleWarningMock = _vitest.vi.spyOn(console, 'warn').mockImplementation(() => {});
    consoleErrorMock = _vitest.vi.spyOn(console, 'error').mockImplementation(() => {});
  });
  afterEach(() => {
    consoleWarningMock.mockRestore();
    consoleErrorMock.mockRestore();
  });
  const types = ['fade', 'scale', 'slide-down', 'slide-up', 'slide-left', 'slide-right'];
  const expectTypeClass = function (type) {
    var _Transition, _Transition2;
    it(`should correctly apply classes for '${type}' with html element`, () => {
      const _render = (0, _react2.render)(_Transition || (_Transition = (0, _jsxRuntime.jsx)(_index.Transition, {
          type: type,
          in: true,
          children: _div2 || (_div2 = (0, _jsxRuntime.jsx)("div", {
            children: "hello"
          }))
        }))),
        getByText = _render.getByText;
      const element = getByText('hello');
      expect(element).toHaveClass(getClass(type, 'entered'));
    });
    it(`should correctly apply classes for '${type}' with Component`, () => {
      const _render2 = (0, _react2.render)(_Transition2 || (_Transition2 = (0, _jsxRuntime.jsx)(_index.Transition, {
          type: type,
          in: true,
          children: _ExampleComponent2 || (_ExampleComponent2 = (0, _jsxRuntime.jsx)(ExampleComponent, {}))
        }))),
        getByText = _render2.getByText;
      const element = getByText(COMPONENT_TEXT);
      expect(element).toHaveClass(getClass(type, 'entered'));
    });
  };
  types.forEach(type => {
    expectTypeClass(type);
  });
  it('should correctly apply enter and exit classes', async () => {
    const type = 'fade';
    const _render3 = (0, _react2.render)((0, _jsxRuntime.jsx)(_index.Transition, {
        type: type,
        in: true,
        children: _div3 || (_div3 = (0, _jsxRuntime.jsx)("div", {
          children: "hello"
        }))
      })),
      getByText = _render3.getByText,
      rerender = _render3.rerender;
    const element = getByText('hello');
    expect(element).toHaveClass(getClass(type, 'entered'));
    rerender((0, _jsxRuntime.jsx)(_index.Transition, {
      type: type,
      in: false,
      children: _div4 || (_div4 = (0, _jsxRuntime.jsx)("div", {
        children: "hello"
      }))
    }));
    await (0, _react2.waitFor)(() => {
      expect(element).toHaveClass(getClass(type, 'exited'));
    });
  });
  it('should remove component from DOM when `unmountOnExit` is set', async () => {
    const _render4 = (0, _react2.render)(_Transition3 || (_Transition3 = (0, _jsxRuntime.jsx)(_index.Transition, {
        type: "fade",
        in: true,
        unmountOnExit: true,
        children: (0, _jsxRuntime.jsx)("div", {
          children: "hello"
        })
      }))),
      getByText = _render4.getByText,
      rerender = _render4.rerender;
    expect(getByText('hello')).toBeInTheDocument();
    rerender(_Transition4 || (_Transition4 = (0, _jsxRuntime.jsx)(_index.Transition, {
      type: "fade",
      in: false,
      unmountOnExit: true,
      children: (0, _jsxRuntime.jsx)("div", {
        children: "hello"
      })
    })));
    await (0, _react2.waitForElementToBeRemoved)(() => getByText('hello'));
  });
  it('should not execute enter transition with `transitionEnter` set to false', async () => {
    const onEntering = _vitest.vi.fn();
    const _render5 = (0, _react2.render)((0, _jsxRuntime.jsx)(_index.Transition, {
        type: "fade",
        in: false,
        transitionEnter: true,
        onEntering: onEntering,
        children: _div5 || (_div5 = (0, _jsxRuntime.jsx)("div", {
          children: "hello"
        }))
      })),
      rerender = _render5.rerender;
    rerender((0, _jsxRuntime.jsx)(_index.Transition, {
      type: "fade",
      in: true,
      transitionEnter: false,
      onEntering: onEntering,
      children: _div6 || (_div6 = (0, _jsxRuntime.jsx)("div", {
        children: "hello"
      }))
    }));
    await (0, _react2.waitFor)(() => {
      expect(onEntering).not.toHaveBeenCalled();
    });
  });
  it('should not execute exit transition with `transitionExit` set to false', async () => {
    const onExiting = _vitest.vi.fn();
    const _render6 = (0, _react2.render)((0, _jsxRuntime.jsx)(_index.Transition, {
        type: "fade",
        in: true,
        transitionExit: false,
        onExiting: onExiting,
        children: _div7 || (_div7 = (0, _jsxRuntime.jsx)("div", {
          children: "hello"
        }))
      })),
      rerender = _render6.rerender;
    rerender((0, _jsxRuntime.jsx)(_index.Transition, {
      type: "fade",
      in: false,
      transitionExit: false,
      onExiting: onExiting,
      children: _div8 || (_div8 = (0, _jsxRuntime.jsx)("div", {
        children: "hello"
      }))
    }));
    await (0, _react2.waitFor)(() => {
      expect(onExiting).not.toHaveBeenCalled();
    });
  });
  it('should correctly call enter methods', async () => {
    const onEnter = _vitest.vi.fn();
    const onEntering = _vitest.vi.fn();
    const onEntered = _vitest.vi.fn();
    (0, _react2.render)((0, _jsxRuntime.jsx)(_index.Transition, {
      type: "fade",
      in: true,
      onEnter: onEnter,
      onEntering: onEntering,
      onEntered: onEntered,
      children: _div9 || (_div9 = (0, _jsxRuntime.jsx)("div", {
        children: "hello"
      }))
    }));
    await (0, _react2.waitFor)(() => {
      expect(onEnter).toHaveBeenCalled();
      expect(onEntering).toHaveBeenCalled();
      expect(onEntered).toHaveBeenCalled();
    });
  });
  it('should correctly call exit methods', async () => {
    const onExit = _vitest.vi.fn();
    const onExiting = _vitest.vi.fn();
    const onExited = _vitest.vi.fn();
    const _render7 = (0, _react2.render)((0, _jsxRuntime.jsx)(_index.Transition, {
        type: "fade",
        in: true,
        onExit: onExit,
        onExiting: onExiting,
        onExited: onExited,
        children: _div10 || (_div10 = (0, _jsxRuntime.jsx)("div", {
          children: "hello"
        }))
      })),
      rerender = _render7.rerender;
    rerender((0, _jsxRuntime.jsx)(_index.Transition, {
      type: "fade",
      in: false,
      onExit: onExit,
      onExiting: onExiting,
      onExited: onExited,
      children: _div11 || (_div11 = (0, _jsxRuntime.jsx)("div", {
        children: "hello"
      }))
    }));
    await (0, _react2.waitFor)(() => {
      expect(onExit).toHaveBeenCalled();
      expect(onExiting).toHaveBeenCalled();
      expect(onExited).toHaveBeenCalled();
    });
  });
});