import React from 'react';
import type { PropValidators } from '@instructure/shared-types';
type TransitionType = 'fade' | 'scale' | 'slide-down' | 'slide-up' | 'slide-left' | 'slide-right';
type TransitionCommonProps = {
    /**
     * Show the component? Triggers the enter or exit animation.
     */
    in?: boolean;
    /**
     * Unmount the component (remove it from the DOM) when it is not shown.
     */
    unmountOnExit?: boolean;
    /**
     * Run the enter animation when the component mounts, if it is initially
     * shown
     */
    transitionOnMount?: boolean;
    /**
     * Run the enter animation
     */
    transitionEnter?: boolean;
    /**
     * Run the exit animation
     */
    transitionExit?: boolean;
    /**
     * Callback fired when transitioning to the next state
     */
    onTransition?: (toState: BaseTransitionStatesType, fromState: BaseTransitionStatesType) => void;
    /**
     * Callback fired before the "entering" classes are applied
     */
    onEnter?: () => void;
    /**
     * Callback fired after the "entering" classes are applied
     */
    onEntering?: () => void;
    /**
     * Callback fired after the "enter" classes are applied
     */
    onEntered?: (type?: TransitionType) => void;
    /**
     * Callback fired before the "exiting" classes are applied
     */
    onExit?: () => void;
    /**
     * Callback fired after the "exiting" classes are applied
     */
    onExiting?: () => void;
    /**
     * Callback fired after the "exited" classes are applied
     */
    onExited?: (type?: TransitionType) => void;
    /**
     * A single element to animate in and out
     */
    children?: React.ReactNode;
    /**
     * provides a reference to the underlying html root element
     */
    elementRef?: (element: Element | null) => void;
};
type OwnProps = {
    /**
     * A Timeout for the animation, in milliseconds, to ensure that a node doesn't
     * transition indefinately if the browser transitionEnd events are
     * canceled or interrupted.
     *
     * By default this is set to a high number (5 seconds) as a failsafe. You should consider
     * setting this to the duration of your animation (or a bit above it).
     */
    enterDelay?: number;
    /**
     * A Timeout for the animation, in milliseconds, to ensure that a node doesn't
     * transition indefinately if the browser transitionEnd events are
     * canceled or interrupted.
     *
     * By default this is set to a high number (5 seconds) as a failsafe. You should consider
     * setting this to the duration of your animation (or a bit above it).
     */
    exitDelay?: number;
    /**
     * the base CSS class for the transition (transitions go here)
     */
    transitionClassName: string;
    /**
     * CSS class or classes applied when the component is exited
     */
    exitedClassName: string;
    /**
     * CSS class or classes applied while the component is exiting
     */
    exitingClassName: string;
    /**
     * CSS class or classes applied when the component is entered
     */
    enteredClassName: string;
    /**
     * CSS class or classes applied while the component is entering
     */
    enteringClassName: string;
    className?: string;
};
type BaseTransitionOwnProps = TransitionCommonProps & OwnProps;
type BaseTransitionProps = BaseTransitionOwnProps;
type CommonPropKeys = keyof TransitionCommonProps;
type PropKeys = keyof BaseTransitionOwnProps;
type AllowedPropKeys = Readonly<Array<PropKeys>>;
declare const transitionCommonPropTypes: PropValidators<CommonPropKeys>;
declare const propTypes: PropValidators<PropKeys>;
declare const allowedProps: AllowedPropKeys;
type BaseTransitionState = {
    transitioning: boolean;
};
type BaseTransitionStateValue = 'EXITED' | 'EXITING' | 'ENTERING' | 'ENTERED';
type BaseTransitionStatesType = -2 | -1 | 1 | 2;
export type { BaseTransitionProps, TransitionCommonProps, TransitionType, BaseTransitionState, BaseTransitionStateValue, BaseTransitionStatesType };
export { propTypes, allowedProps, transitionCommonPropTypes };
//# sourceMappingURL=props.d.ts.map